@@ -10,12 +10,12 @@ xml_loaded (GstXML * xml, GstObject * object, xmlNodePtr self, gpointer data)
   xmlNodePtr children = self->xmlChildrenNode;
 
   while (children) {
-    if (!strcmp (children->name, "comment")) {
+    if (!strcmp ((char *) children->name, "comment")) {
       xmlNodePtr nodes = children->xmlChildrenNode;
 
       while (nodes) {
-        if (!strcmp (nodes->name, "text")) {
-          gchar *name = g_strdup (xmlNodeGetContent (nodes));
+        if (!strcmp ((char *) nodes->name, "text")) {
+          gchar *name = g_strdup ((char *) xmlNodeGetContent (nodes));
 
           g_print ("object %s loaded with comment '%s'\n",
               gst_object_get_name (object), name);
@@ -42,13 +42,13 @@ main (int argc, char *argv[])
 /*		    G_CALLBACK (xml_loaded), xml); */
 
   if (argc == 2)
-    ret = gst_xml_parse_file (xml, argv[1], NULL);
+    ret = gst_xml_parse_file (xml, (guchar *) argv[1], NULL);
   else
-    ret = gst_xml_parse_file (xml, "xmlTest.gst", NULL);
+    ret = gst_xml_parse_file (xml, (guchar *) "xmlTest.gst", NULL);
 
   g_assert (ret == TRUE);
 
-  pipeline = gst_xml_get_element (xml, "pipeline");
+  pipeline = gst_xml_get_element (xml, (guchar *) "pipeline");
   g_assert (pipeline != NULL);
 
   gst_element_set_state (pipeline, GST_STATE_PLAYING);
