@@ -67,8 +67,6 @@ static gboolean init_post (void);
 
 static GSList *preload_plugins = NULL;
 
-const gchar *g_log_domain_gstreamer = "GStreamer";
-
 static void
 debug_log_handler (const gchar * log_domain,
     GLogLevelFlags log_level, const gchar * message, gpointer user_data)
@@ -348,6 +346,10 @@ gst_init_check_with_popt_table (int *argc, char **argv[],
   }
 
   if (popt_options == NULL) {
+    /* check for GST_DEBUG_NO_COLOR environment variable */
+    if (g_getenv ("GST_DEBUG_NO_COLOR") != NULL)
+      gst_debug_set_colored (FALSE);
+
     options = options_without;
   } else {
     options = options_with;
@@ -471,6 +473,9 @@ init_pre (void)
   {
     const gchar *debug_list;
 
+    if (g_getenv ("GST_DEBUG_NO_COLOR") != NULL)
+      gst_debug_set_colored (FALSE);
+
     debug_list = g_getenv ("GST_DEBUG");
     if (debug_list) {
       parse_debug_list (debug_list);
@@ -576,7 +581,7 @@ init_post (void)
 #endif /* GST_DISABLE_TRACE */
 
   llf = G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_ERROR | G_LOG_FLAG_FATAL;
-  g_log_set_handler (g_log_domain_gstreamer, llf, debug_log_handler, NULL);
+  g_log_set_handler (G_LOG_DOMAIN, llf, debug_log_handler, NULL);
 
   _gst_format_initialize ();
   _gst_query_type_initialize ();
