@@ -242,6 +242,24 @@ gst_value_list_append_value (GValue * value, const GValue * append_value)
 
   g_return_if_fail (GST_VALUE_HOLDS_LIST (value)
       || GST_VALUE_HOLDS_FIXED_LIST (value));
+#ifndef G_DISABLE_CHECKS
+  if (GST_VALUE_HOLDS_LIST (value)) {
+    guint i;
+
+    for (i = 0; i < gst_value_list_get_size (value); i++) {
+      const GValue *v = gst_value_list_get_value (value, i);
+
+      if (gst_value_compare (v, append_value) == GST_VALUE_EQUAL) {
+        gchar *s = gst_value_serialize (append_value);
+
+        g_warning ("attempting to add value %s to list twice",
+            GST_STR_NULL (s));
+        g_free (s);
+        return;
+      }
+    }
+  }
+#endif
 
   gst_value_init_and_copy (&val, append_value);
   g_array_append_vals ((GArray *) value->data[0].v_pointer, &val, 1);
@@ -961,7 +979,7 @@ gst_value_deserialize_boolean (GValue * dest, const char *s)
  * int *
  *******/
 
-static int
+static long long
 gst_strtoll (const char *s, char **end, int base)
 {
   long long i;
@@ -1001,10 +1019,11 @@ gst_value_serialize_ ## _type (const GValue * value) \
 
 static gboolean
 gst_value_deserialize_int_helper (long long *to, const char *s, long long min,
-    long long max)
+    long long max, int size)
 {
   gboolean ret = FALSE;
   char *end;
+  long long mask = -1;
 
   *to = gst_strtoll (s, &end, 0);
   if (*end == 0) {
@@ -1028,8 +1047,23 @@ gst_value_deserialize_int_helper (long long *to, const char *s, long long min,
     }
   }
   if (ret) {
-    if (*to < min || *to > max) {
-      ret = FALSE;
+    /* by definition, a long long fits into a long long; so ignore those */
+    if (size != sizeof (mask)) {
+      if (*to >= 0) {
+        /* for positive numbers, we create a mask of 1's outside of the range
+         * and 0's inside the range.  An and will thus keep only 1 bits
+         * outside of the range */
+        mask <<= (size * 8);
+        if ((mask & *to) != 0) {
+          ret = FALSE;
+        }
+      } else {
+        /* for negative numbers, we do a 2's complement version */
+        mask <<= ((size * 8) - 1);
+        if ((mask & *to) != mask) {
+          ret = FALSE;
+        }
+      }
     }
   }
   return ret;
@@ -1042,9 +1076,11 @@ static gboolean \
 gst_value_deserialize_ ## _type (GValue * dest, const char *s) \
 { \
   long long x; \
+  g ## _type y; \
 \
-  if (gst_value_deserialize_int_helper (&x, s, G_MIN ## _macro, G_MAX ## _macro)) { \
-    g_value_set_ ## _type (dest, x); \
+  if (gst_value_deserialize_int_helper (&x, s, G_MIN ## _macro, G_MAX ## _macro, sizeof (g ##_type))) { \
+    y = x; \
+    g_value_set_ ## _type (dest, y); \
     return TRUE; \
   } else { \
     return FALSE; \
@@ -1103,18 +1139,19 @@ gst_value_deserialize_ ## _type (GValue * dest, const char *s) \
   gst_value_register (&gst_value); \
 } G_STMT_END
 
-CREATE_SERIALIZATION (int, INT)
-    CREATE_SERIALIZATION (int64, INT64)
-    CREATE_SERIALIZATION (long, LONG)
-CREATE_USERIALIZATION (uint, UINT)
-CREATE_USERIALIZATION (uint64, UINT64)
-CREATE_USERIALIZATION (ulong, ULONG)
+CREATE_SERIALIZATION (int, INT);
+CREATE_SERIALIZATION (int64, INT64);
+CREATE_SERIALIZATION (long, LONG);
+
+CREATE_USERIALIZATION (uint, UINT);
+CREATE_USERIALIZATION (uint64, UINT64);
+CREATE_USERIALIZATION (ulong, ULONG);
 
 /**********
  * double *
  **********/
-     static int
-         gst_value_compare_double (const GValue * value1, const GValue * value2)
+static int
+gst_value_compare_double (const GValue * value1, const GValue * value2)
 {
   if (value1->data[0].v_double > value2->data[0].v_double)
     return GST_VALUE_GREATER_THAN;
@@ -1573,6 +1610,7 @@ gst_value_intersect_list (GValue * dest, const GValue * value1,
         gst_value_init_and_copy (&temp, dest);
         g_value_unset (dest);
         gst_value_list_concat (dest, &temp, &intersection);
+        g_value_unset (&temp);
       }
       g_value_unset (&intersection);
     }
